==> kalgebra-15.12.1.tar.xz: kalgebra-15.12.1/src/main.cpp <==
/*************************************************************************************
 *  Copyright (C) 2007 by Aleix Pol <aleixpol@kde.org>                               *
 *                                                                                   *
 *  This program is free software; you can redistribute it and/or                    *
 *  modify it under the terms of the GNU General Public License                      *
 *  as published by the Free Software Foundation; either version 2                   *
 *  of the License, or (at your option) any later version.                           *
 *                                                                                   *
 *  This program is distributed in the hope that it will be useful,                  *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                    *
 *  GNU General Public License for more details.                                     *
 *                                                                                   *
 *  You should have received a copy of the GNU General Public License                *
 *  along with this program; if not, write to the Free Software                      *
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA   *
 *************************************************************************************/

#include <QApplication>
#include "kalgebra.h"
#include <klocalizedstring.h>

int main(int argc, char *argv[])
{
    QApplication app(argc, argv);
    app.setApplicationName(QStringLiteral("kalgebra"));
    app.setOrganizationDomain(QStringLiteral("kde.org"));
    app.setApplicationDisplayName(i18n("KAlgebra"));
    app.setApplicationVersion(QStringLiteral("0.99"));
    
        KLocalizedString::setApplicationDomain("kalgebra");

    KAlgebra widget;
    widget.show();
    
    return app.exec();
}

==> kalgebra_15.12.3.orig.tar.xz: kalgebra-15.12.3/src/main.cpp <==
/*************************************************************************************
 *  Copyright (C) 2007 by Aleix Pol <aleixpol@kde.org>                               *
 *                                                                                   *
 *  This program is free software; you can redistribute it and/or                    *
 *  modify it under the terms of the GNU General Public License                      *
 *  as published by the Free Software Foundation; either version 2                   *
 *  of the License, or (at your option) any later version.                           *
 *                                                                                   *
 *  This program is distributed in the hope that it will be useful,                  *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                    *
 *  GNU General Public License for more details.                                     *
 *                                                                                   *
 *  You should have received a copy of the GNU General Public License                *
 *  along with this program; if not, write to the Free Software                      *
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA   *
 *************************************************************************************/

#include <QApplication>
#include <KAboutData>
#include "kalgebra.h"
#include <klocalizedstring.h>

int main(int argc, char *argv[])
{
    QApplication app(argc, argv);
    KAboutData about("kalgebra", "KAlgebra", "0.10", i18n("A portable calculator"),
             KAboutLicense::GPL, i18n("(C) 2006-2016 Aleix Pol i Gonzalez"));
    about.addAuthor( "Aleix Pol i Gonzalez", QString(), "aleixpol@kde.org" );
    about.setTranslator(i18nc("NAME OF TRANSLATORS", "Your names"), i18nc("EMAIL OF TRANSLATORS", "Your emails"));
    KAboutData::setApplicationData(about);

    KLocalizedString::setApplicationDomain("kalgebra");

    KAlgebra widget;
    widget.show();
    
    return app.exec();
}
